@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: bib2bib.ml,v 1.24 2008-01-08 13:32:42 filliatr Exp $ i*)
+(*i $Id: bib2bib.ml,v 1.27 2008-12-11 16:05:55 marche Exp $ i*)
 
 open Printf
 open Bibtex
@@ -49,6 +49,8 @@ let add_condition c =
 
 let expand_abbrevs = ref false
 
+let expand_xrefs = ref false
+
 let sort_criteria = ref []
 
 let reverse_sort = ref false
@@ -61,14 +63,18 @@ let args_spec =
      "citations output file name");
     ("-c", Arg.String (add_condition),"filter condition");
     ("-w", Arg.Set Options.warn_error, "stop on warning");
+    ("--warn-error", Arg.Set Options.warn_error, "stop on warning");
     ("-d", Arg.Set Options.debug, "debug flag");
     ("-q", Arg.Set Options.quiet, "quiet flag");
+    ("--quiet", Arg.Set Options.quiet, "quiet flag");
     ("-s", Arg.String (fun s -> sort_criteria := (String.lowercase s):: !sort_criteria),
      "sort with respect to keys or a given field");
     ("-r", Arg.Set reverse_sort,
      "reverse the sort order");
     ("--expand", Arg.Unit (fun () -> expand_abbrevs := true), 
      "expand the abbreviations");
+    ("--expand-xrefs", Arg.Unit (fun () -> expand_xrefs := true), 
+     "expand the cross-references");
     ("--version", Arg.Unit (fun () -> Copying.banner "bib2bib"; exit 0), 
      "print version and exit");
     ("--warranty", 
@@ -127,13 +133,13 @@ let output_bib_file biblio keys =
     exit 1 
 
 
-let rec make_compare_fun criteria c1 c2 =
+let rec make_compare_fun db criteria c1 c2 =
   match criteria with
     | [] -> 0	
     | field :: rem ->
 	let comp = 
 	  match field with
-	    | "$KEY"  ->
+	    | "$key"  ->
 		begin
 		  match (c1,c2) with
 		    | (Abbrev(s1,_),Abbrev(s2,_))
@@ -141,14 +147,23 @@ let rec make_compare_fun criteria c1 c2 =
 			compare s1 s2
 		    | _ -> 0
 		end
-	    | "$TYPE" ->
+	    | "$type" ->
 		begin
 		  match (c1,c2) with
 		    | (Entry(s1,_,_),Entry(s2,_,_)) ->
 			compare s1 s2
 		    | _ -> 0
 		end
-	    | _ ->
+	    | "$date" -> 
+		begin
+		  match (c1,c2) with
+		    | (Entry(s1,t1,l1),Entry(s2,t2,l2)) ->
+			Expand.date_compare db 
+			  (s1,t1,Expand.expand_fields l1) 
+			  (s2,t2,Expand.expand_fields l2)
+		    | _ -> 0
+		end
+	    | f ->
 		begin
 		  match (c1,c2) with
 		    | (Entry(_,_,l1),Entry(_,_,l2)) ->
@@ -174,7 +189,7 @@ let rec make_compare_fun criteria c1 c2 =
 		end
 	in
 	if comp = 0
-	then make_compare_fun rem c1 c2
+	then make_compare_fun db rem c1 c2
 	else 
 	  if !reverse_sort then -comp else comp
 ;;
@@ -203,10 +218,10 @@ let main () =
       !input_file_names
       empty_biblio
   in 
-  let expanded = Bibtex.expand_abbrevs all_entries
-  in
+  let abbrv_expanded = Bibtex.expand_abbrevs all_entries in
+  let xref_expanded = Bibtex.expand_crossrefs abbrv_expanded in
   let matching_keys =
-    Bibfilter.filter (Bibtex.expand_crossrefs expanded)
+    Bibfilter.filter xref_expanded
       (fun e k f -> Condition.evaluate_cond e k f !condition) 
   in
   if KeySet.cardinal matching_keys = 0 then
@@ -215,13 +230,19 @@ let main () =
       if !Options.warn_error then exit 2;
     end;
   
-  let user_expanded = if !expand_abbrevs then expanded else all_entries in
+  let user_expanded = 
+    if !expand_abbrevs then 
+      if !expand_xrefs then xref_expanded else abbrv_expanded 
+    else 
+      if !expand_xrefs then Bibtex.expand_crossrefs all_entries 
+      else all_entries
+  in
   let needed_keys = Bibfilter.saturate user_expanded matching_keys in
   (* this should be to right place to sort the output bibliography *)
   let final_bib =
     if !sort_criteria = [] then user_expanded
     else      
-      let comp = make_compare_fun (List.rev !sort_criteria) in
+      let comp = make_compare_fun (Expand.expand user_expanded) (List.rev !sort_criteria) in
       eprintf "Sorting...";
       let b = Bibtex.sort comp user_expanded in
       eprintf "done.\n";
