@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: expand.mli,v 1.5 2008-01-08 13:32:42 filliatr Exp $ i*)
+(*i $Id: expand.mli,v 1.6 2008-12-11 16:05:55 marche Exp $ i*)
 
 (*s Expansion of abbreviations in BibTeX databases. *)
 
@@ -24,10 +24,14 @@ type entry = Bibtex.entry_type * Bibtex.key * fields
 		
 val expand : Bibtex.biblio -> entry list
 
+val expand_fields : (string * Bibtex.atom list) list -> (string * string) list
+
 (*s Compare the dates of two entries. *)
 
 val date_order : entry list -> entry -> entry -> bool
 
+val date_compare : entry list -> entry -> entry -> int
+
 (*s Access to the fields of a given entry. *)
 
 val get_field : entry -> string -> string
