@@ -14,26 +14,10 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: parse_condition.ml,v 1.4 2001/02/21 09:51:54 filliatr Exp $ i*)
+(*i $Id: parse_condition.ml,v 1.5 2008-01-08 13:32:42 filliatr Exp $ i*)
 
 open Condition
 
-(*
-let condition s =
-  try
-    let n = String.index s ':' in 
-    let field = String.uppercase (String.sub s 0 n)
-    and filter = String.sub s (succ n) (String.length s - n - 1)
-    in
-      Printf.printf "champ = %s\n" field;
-      Printf.printf "filter = %s\n" filter;
-      Match (Field field,Str.regexp_case_fold filter)
-  with 
-      Not_found ->
-	raise Syntax_error
-;;
-*)
-
 let condition s =
   let b = Lexing.from_string s in
   Condition_parser.condition_start Condition_lexer.token b
